
#ifndef KASTENCONTROLLERS_EXPORT_H
#define KASTENCONTROLLERS_EXPORT_H

#ifdef KASTENCONTROLLERS_STATIC_DEFINE
#  define KASTENCONTROLLERS_EXPORT
#  define KASTENCONTROLLERS_NO_EXPORT
#else
#  ifndef KASTENCONTROLLERS_EXPORT
#    ifdef KastenControllers_EXPORTS
        /* We are building this library */
#      define KASTENCONTROLLERS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KASTENCONTROLLERS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KASTENCONTROLLERS_NO_EXPORT
#    define KASTENCONTROLLERS_NO_EXPORT 
#  endif
#endif

#ifndef KASTENCONTROLLERS_DEPRECATED
#  define KASTENCONTROLLERS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KASTENCONTROLLERS_DEPRECATED_EXPORT
#  define KASTENCONTROLLERS_DEPRECATED_EXPORT KASTENCONTROLLERS_EXPORT KASTENCONTROLLERS_DEPRECATED
#endif

#ifndef KASTENCONTROLLERS_DEPRECATED_NO_EXPORT
#  define KASTENCONTROLLERS_DEPRECATED_NO_EXPORT KASTENCONTROLLERS_NO_EXPORT KASTENCONTROLLERS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KASTENCONTROLLERS_NO_DEPRECATED
#    define KASTENCONTROLLERS_NO_DEPRECATED
#  endif
#endif

#endif
